@@ -10,17 +10,14 @@ DEFAULT_TOKEN_FILE = "api_token.txt"
 
 
 class APIToken:
-
     def __refresh_token(self, token):
-        data = {
-            "refresh": token
-        }
+        data = {"refresh": token}
         url = self.instance + "/api/auth/refresh-token"
         resp = requests.post(url=url, json=data)
         resp_data = resp.json()
         if resp.status_code == 200:
             # Save new sets of token into token file.
-            with open(self.token_file, 'w') as fp:
+            with open(self.token_file, "w") as fp:
                 fp.write(str(resp_data["refresh"]))
 
             return resp_data["access"]
@@ -36,15 +33,19 @@ class APIToken:
             refresh = None
             try:
                 # read current refresh-able token
-                with open(self.token_file, 'r') as fp:
+                with open(self.token_file, "r") as fp:
                     refresh = fp.read()
                 # make sure token does exist
                 if not refresh:
-                    logger.error("No API token specified in file: {}".format(self.token_file))
+                    logger.error(
+                        f"No API token specified in file: {self.token_file}"
+                    )
                     return None
             except FileNotFoundError:
                 # No token file exists
-                logger.error("No token file exists with given name: {}".format(self.token_file))
+                logger.error(
+                    f"No token file exists with given name: {self.token_file}"
+                )
                 return None
 
             # refresh given token
@@ -52,7 +53,9 @@ class APIToken:
                 self.__api_token = self.__refresh_token(refresh)
             except IntelOwlInvalidAPITokenException as e:
                 logger.exception(e)
-                logger.error("API token is invalid. Please ask the administrator to provide you with a new token")
+                logger.error(
+                    "API token is invalid. Please ask the administrator to provide you with a new token"
+                )
                 return None
 
         return self.__api_token
@@ -61,7 +64,9 @@ class APIToken:
         token = self.__get_token()
         if token:
             return token
-        raise IntelOwlInvalidAPITokenException("pyintelowl failed. API token is invalid.")
+        raise IntelOwlInvalidAPITokenException(
+            "pyintelowl failed. API token is invalid."
+        )
 
     def __init__(self, token_file, instance):
         self.token_file = token_file
